==> hugo_0.37.1.orig.tar.gz: hugo-0.37.1/docs/content/commands/hugo_server.md <==
---
date: 2018-01-31T11:40:21+01:00
title: "hugo server"
slug: hugo_server
url: /commands/hugo_server/
---
## hugo server

A high performance webserver

### Synopsis

Hugo provides its own webserver which builds and serves the site.
While hugo server is high performance, it is a webserver with limited options.
Many run it in production, but the standard behavior is for people to use it
in development and use a more full featured server such as Nginx or Caddy.

'hugo server' will avoid writing the rendered and served content to disk,
preferring to store it in memory.

By default hugo will also watch your files for any changes you make and
automatically rebuild the site. It will then live reload any open browser pages
and push the latest content to them. As most Hugo sites are built in a fraction
of a second, you will be able to save and see your changes nearly instantly.

```
hugo server [flags]
```

### Options

```
      --appendPort                 append port to baseURL (default true)
  -b, --baseURL string             hostname (and path) to the root, e.g. http://spf13.com/
      --bind string                interface to which the server will bind (default "127.0.0.1")
  -D, --buildDrafts                include content marked as draft
  -E, --buildExpired               include expired content
  -F, --buildFuture                include content with publishdate in the future
      --cacheDir string            filesystem path to cache directory. Defaults: $TMPDIR/hugo_cache/
      --canonifyURLs               (deprecated) if true, all relative URLs will be canonicalized using baseURL
      --cleanDestinationDir        remove files from destination not found in static directories
  -c, --contentDir string          filesystem path to content directory
  -d, --destination string         filesystem path to write files to
      --disableFastRender          enables full re-renders on changes
      --disableKinds stringSlice   disable different kind of pages (home, RSS etc.)
      --disableLiveReload          watch without enabling live browser reload on rebuild
      --enableGitInfo              add Git revision, date and author info to the pages
      --forceSyncStatic            copy all files when static is changed.
      --gc                         enable to run some cleanup tasks (remove unused cache files) after the build
  -h, --help                       help for server
      --i18n-warnings              print missing translations
      --ignoreCache                ignores the cache directory
  -l, --layoutDir string           filesystem path to layout directory
      --liveReloadPort int         port for live reloading (i.e. 443 in HTTPS proxy situations) (default -1)
      --meminterval string         interval to poll memory usage (requires --memstats), valid time units are "ns", "us" (or "µs"), "ms", "s", "m", "h". (default "100ms")
      --memstats string            log memory usage to this file
      --navigateToChanged          navigate to changed content file on live browser reload
      --noChmod                    don't sync permission mode of files
      --noHTTPCache                prevent HTTP caching
      --noTimes                    don't sync modification time of files
      --pluralizeListTitles        (deprecated) pluralize titles in lists using inflect (default true)
  -p, --port int                   port on which the server will listen (default 1313)
      --preserveTaxonomyNames      (deprecated) preserve taxonomy names as written ("Gérard Depardieu" vs "gerard-depardieu")
      --renderToDisk               render to Destination path (default is render to memory & serve from there)
  -s, --source string              filesystem path to read files relative from
      --stepAnalysis               display memory and timing of different steps of the program
      --templateMetrics            display metrics about template executions
      --templateMetricsHints       calculate some improvement hints when combined with --templateMetrics
  -t, --theme string               theme to use (located in /themes/THEMENAME/)
      --themesDir string           filesystem path to themes directory
      --uglyURLs                   (deprecated) if true, use /filename.html instead of /filename/
  -w, --watch                      watch filesystem for changes and recreate as needed (default true)
```

### Options inherited from parent commands

```
      --config string    config file (default is path/config.yaml|json|toml)
      --debug            debug output
      --log              enable Logging
      --logFile string   log File path (if set, logging enabled automatically)
      --quiet            build in quiet mode
  -v, --verbose          verbose output
      --verboseLog       verbose logging
```

### SEE ALSO

* [hugo](/commands/hugo/)	 - hugo builds your site

###### Auto generated by spf13/cobra on 31-Jan-2018

==> hugo_0.40.1.orig.tar.gz: hugo-0.40.1/docs/content/commands/hugo_server.md <==
---
date: 2018-04-16
title: "hugo server"
slug: hugo_server
url: /commands/hugo_server/
---
## hugo server

A high performance webserver

### Synopsis

Hugo provides its own webserver which builds and serves the site.
While hugo server is high performance, it is a webserver with limited options.
Many run it in production, but the standard behavior is for people to use it
in development and use a more full featured server such as Nginx or Caddy.

'hugo server' will avoid writing the rendered and served content to disk,
preferring to store it in memory.

By default hugo will also watch your files for any changes you make and
automatically rebuild the site. It will then live reload any open browser pages
and push the latest content to them. As most Hugo sites are built in a fraction
of a second, you will be able to save and see your changes nearly instantly.

```
hugo server [flags]
```

### Options

```
      --appendPort                 append port to baseURL (default true)
  -b, --baseURL string             hostname (and path) to the root, e.g. http://spf13.com/
      --bind string                interface to which the server will bind (default "127.0.0.1")
  -D, --buildDrafts                include content marked as draft
  -E, --buildExpired               include expired content
  -F, --buildFuture                include content with publishdate in the future
      --cacheDir string            filesystem path to cache directory. Defaults: $TMPDIR/hugo_cache/
      --canonifyURLs               (deprecated) if true, all relative URLs will be canonicalized using baseURL
      --cleanDestinationDir        remove files from destination not found in static directories
  -c, --contentDir string          filesystem path to content directory
  -d, --destination string         filesystem path to write files to
      --disableFastRender          enables full re-renders on changes
      --disableKinds stringSlice   disable different kind of pages (home, RSS etc.)
      --disableLiveReload          watch without enabling live browser reload on rebuild
      --enableGitInfo              add Git revision, date and author info to the pages
      --forceSyncStatic            copy all files when static is changed.
      --gc                         enable to run some cleanup tasks (remove unused cache files) after the build
  -h, --help                       help for server
      --i18n-warnings              print missing translations
      --ignoreCache                ignores the cache directory
  -l, --layoutDir string           filesystem path to layout directory
      --liveReloadPort int         port for live reloading (i.e. 443 in HTTPS proxy situations) (default -1)
      --meminterval string         interval to poll memory usage (requires --memstats), valid time units are "ns", "us" (or "µs"), "ms", "s", "m", "h". (default "100ms")
      --memstats string            log memory usage to this file
      --navigateToChanged          navigate to changed content file on live browser reload
      --noChmod                    don't sync permission mode of files
      --noHTTPCache                prevent HTTP caching
      --noTimes                    don't sync modification time of files
      --pluralizeListTitles        (deprecated) pluralize titles in lists using inflect (default true)
  -p, --port int                   port on which the server will listen (default 1313)
      --preserveTaxonomyNames      (deprecated) preserve taxonomy names as written ("Gérard Depardieu" vs "gerard-depardieu")
      --renderToDisk               render to Destination path (default is render to memory & serve from there)
  -s, --source string              filesystem path to read files relative from
      --stepAnalysis               display memory and timing of different steps of the program
      --templateMetrics            display metrics about template executions
      --templateMetricsHints       calculate some improvement hints when combined with --templateMetrics
  -t, --theme string               theme to use (located in /themes/THEMENAME/)
      --themesDir string           filesystem path to themes directory
      --uglyURLs                   (deprecated) if true, use /filename.html instead of /filename/
  -w, --watch                      watch filesystem for changes and recreate as needed (default true)
```

### Options inherited from parent commands

```
      --config string    config file (default is path/config.yaml|json|toml)
      --debug            debug output
      --log              enable Logging
      --logFile string   log File path (if set, logging enabled automatically)
      --quiet            build in quiet mode
  -v, --verbose          verbose output
      --verboseLog       verbose logging
```

### SEE ALSO

* [hugo](/commands/hugo/)	 - hugo builds your site

###### Auto generated by spf13/cobra on 16-Apr-2018
